package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbTypeCourse;

import java.util.List;

/**
 * 类型课程关联Service接口
 *
 * @author ruoyi
 * @date 2024-09-19
 */
public interface ITbTypeCourseService
{
    /**
     * 查询类型课程关联
     *
     * @param typeCourseId 类型课程关联主键
     * @return 类型课程关联
     */
    public TbTypeCourse selectTbTypeCourseByTypeCourseId(Long typeCourseId);

    /**
     * 查询类型课程关联列表
     *
     * @param tbTypeCourse 类型课程关联
     * @return 类型课程关联集合
     */
    public List<TbTypeCourse> selectTbTypeCourseList(TbTypeCourse tbTypeCourse);

    /**
     * 新增类型课程关联
     *
     * @param tbTypeCourse 类型课程关联
     * @return 结果
     */
    public int insertTbTypeCourse(TbTypeCourse tbTypeCourse);

    /**
     * 修改类型课程关联
     *
     * @param tbTypeCourse 类型课程关联
     * @return 结果
     */
    public int updateTbTypeCourse(TbTypeCourse tbTypeCourse);

    /**
     * 批量删除类型课程关联
     *
     * @param typeCourseIds 需要删除的类型课程关联主键集合
     * @return 结果
     */
    public int deleteTbTypeCourseByTypeCourseIds(Long[] typeCourseIds);

    /**
     * 删除类型课程关联信息
     *
     * @param typeCourseId 类型课程关联主键
     * @return 结果
     */
    public int deleteTbTypeCourseByTypeCourseId(Long typeCourseId);

    /**
     * 根据课程ID删除类型课程关联信息
     *
     * @param courseId 课程ID
     * @return 结果
     */
    public int deleteTbTypeCourseByCourseId(Long courseId);

    /**
     * 批量新增类型课程关联
     *
     * @param classIds 分类组
     * @param courseId 课程ID
     * @return 结果
     */
    public int batchInsertTbTypeCourse(Long[] classIds, Long courseId);
}
